"""the instance of SQLAlchemy from Flask-SQLAlchemy

"""
from flask_sqlalchemy import SQLAlchemy

##__________________________________________________________________||
sa = SQLAlchemy()
"""the instance of SQLAlchemy from Flask-SQLAlchemy

The instance is named "sa" here. However, it is more commonly named
"db" in example code found online.

- API: https://flask-sqlalchemy.palletsprojects.com/en/2.x/api/#flask_sqlalchemy.SQLAlchemy
- The difference from the plain SQLAlchemy:
  https://flask-sqlalchemy.palletsprojects.com/en/2.x/api/#flask_sqlalchemy.SQLAlchemy

"""
##__________________________________________________________________||
